@@ -34,7 +34,7 @@ def on_delete(req, resp, requester):
     if not (challenger == requester or check_ical_key_admin(challenger)):
         raise HTTPForbidden(
             'Unauthorized',
-            'Action not allowed: "%s" is not allowed to delete ical_keys of "%s"' % (challenger, ),
+            'Action not allowed: "%s" is not allowed to delete ical_keys of "%s"' % (challenger, requester),
         )
 
     invalidate_ical_key_by_requester(requester)
